Package: rcdk
Version: 3.8.2
Date: 2025-11-30
Title: Interface to the 'CDK' Libraries
Authors@R: c(
  person('Rajarshi', 'Guha', ,'rajarshi.guha@gmail.com', role=c('aut',"cph"),
    comment = c(ORCID = "0000-0001-7403-8819")),
  person('Zachary', 'Charlop-Powers', ,'zach.charlop.powers@gmail.com',role=c('cre'),
      comment = c(ORCID = "0000-0001-8816-4680")),
  person('Emma', 'Schymanski', ,'schymane@gmail.com', role=c('ctb'),
      comment = c(ORCID = "0000-0001-6868-8145")),
  person('Egon', 'Willighagen', ,'egon.willighagen@maastrichtuniversity.nl', role=c('ctb'),
      comment = c(ORCID = "0000-0001-7542-0286")))
Depends: rcdklibs (>= 2.9)
Imports: fingerprint, rJava, methods, png, iterators, itertools
Suggests: xtable, RUnit, knitr, rmarkdown, devtools
License: LGPL
URL: https://github.com/CDK-R/cdkr
LazyLoad: yes
LazyData: true
SystemRequirements: Java (>= 8)
BugReports: https://github.com/CDK-R/cdkr/issues
Description: Allows the user to access functionality in the
    'CDK', a Java framework for cheminformatics. This allows the user to load
    molecules, evaluate fingerprints, calculate molecular descriptors and so on.
    In addition, the 'CDK' API allows the user to view structures in 2D.
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2025-11-30 15:59:31 UTC; zcpowers
Author: Rajarshi Guha [aut, cph] (ORCID:
    <https://orcid.org/0000-0001-7403-8819>),
  Zachary Charlop-Powers [cre] (ORCID:
    <https://orcid.org/0000-0001-8816-4680>),
  Emma Schymanski [ctb] (ORCID: <https://orcid.org/0000-0001-6868-8145>),
  Egon Willighagen [ctb] (ORCID: <https://orcid.org/0000-0001-7542-0286>)
Maintainer: Zachary Charlop-Powers <zach.charlop.powers@gmail.com>
Repository: CRAN
Date/Publication: 2025-11-30 16:40:08 UTC
Built: R 4.6.0; ; 2026-04-27 09:18:02 UTC; unix
