# Generated by roxygen2: do not edit by hand

S3method(hasNext,iload.molecules)
export(cdk.version)
export(compare.isotope.pattern)
export(convert.implicit.to.explicit)
export(copy.image.to.clipboard)
export(do.aromaticity)
export(do.isotopes)
export(do.typing)
export(eval.atomic.desc)
export(eval.desc)
export(generate.2d.coordinates)
export(generate.formula)
export(generate.formula.iter)
export(get.adjacency.matrix)
export(get.alogp)
export(get.atom.count)
export(get.atom.index)
export(get.atomic.desc.names)
export(get.atomic.number)
export(get.atoms)
export(get.bond.order)
export(get.bonds)
export(get.charge)
export(get.chem.object.builder)
export(get.connected.atom)
export(get.connected.atoms)
export(get.connection.matrix)
export(get.depictor)
export(get.desc.categories)
export(get.desc.names)
export(get.element.types)
export(get.exact.mass)
export(get.exhaustive.fragments)
export(get.fingerprint)
export(get.formal.charge)
export(get.formula)
export(get.hydrogen.count)
export(get.isotopes.pattern)
export(get.largest.component)
export(get.mcs)
export(get.mol2formula)
export(get.murcko.fragments)
export(get.natural.mass)
export(get.point2d)
export(get.point3d)
export(get.properties)
export(get.property)
export(get.smiles)
export(get.smiles.parser)
export(get.stereo.types)
export(get.stereocenters)
export(get.symbol)
export(get.title)
export(get.total.charge)
export(get.total.formal.charge)
export(get.total.hydrogen.count)
export(get.tpsa)
export(get.volume)
export(get.xlogp)
export(iload.molecules)
export(is.aliphatic)
export(is.aromatic)
export(is.connected)
export(is.in.ring)
export(is.neutral)
export(isvalid.formula)
export(load.molecules)
export(matches)
export(parse.smiles)
export(remove.hydrogens)
export(remove.property)
export(set.atom.types)
export(set.charge.formula)
export(set.property)
export(set.title)
export(smiles.flavors)
export(view.image.2d)
export(view.molecule.2d)
export(view.table)
export(write.molecules)
import(fingerprint)
import(iterators)
import(itertools)
import(methods)
import(png)
import(rJava)
import(rcdklibs)
importFrom(itertools,hasNext)
importFrom(utils,download.file)
importFrom(utils,write.table)
