% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/formula.R
\name{isvalid.formula}
\alias{isvalid.formula}
\title{isvalid.formula}
\usage{
isvalid.formula(formula, rule = c("nitrogen", "RDBE"))
}
\arguments{
\item{formula}{Required. A CDK Formula}

\item{rule}{Optional. Default \code{rule=c("nitrogen","RDBE")}}
}
\description{
Validate a cdkFormula.
}
