% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/formula.R
\name{set.charge.formula}
\alias{set.charge.formula}
\title{set.charge.formula}
\usage{
set.charge.formula(formula, charge = -1)
}
\arguments{
\item{formula}{Required. Molecular formula}

\item{charge}{Optional. Default \code{-1}}
}
\description{
Set the charge to a cdkFormula function.
}
